local compostables = {
	"underch:green_mushroom",
	"default:apple",
	"farming:eggplant",
	"ethereal:fern_tubers",
	"farming:parsley",
	"farming:asparagus",
	"farming:potato",
	"underch:dry_moss",
	"farming:pineapple_ring",
	"underch:torchberries",
	"farming:seed_rice",
	"underch:orange_mushroom",
	"underch:underground_vine",
	"underch:moss",
	"ethereal:pine_nuts",
	"farming:seed_oat",
	"default:cactus",
	"default:papyrus",
	"ethereal:fern",
	"ethereal:illumishroom1",
	"ethereal:illumishroom2",
	"ethereal:illumishroom3",
	"techage:leave_powder",
	"techage:needle_powder",
	"flowers:mushroom_red",
	"flowers:mushroom_brown",
	"underch:mossy_dirt",
	"underch:burning_mushroom",
	"underch:fiery_vine",
	"underch:mould",
	"underch:dead_bush",
}

for _,item in pairs(compostables) do compost.register_item(item) end

core.register_craft({
	type = "shapeless",
	output = "bonemeal:mulch 2",
	recipe = {"compost:compost"},
})
